==> plantuml-libs-7.1.0.tgz: package/distribution/fontawesome-6/Brands/SquareFontAwesomeStroke.md <==
# SquareFontAwesomeStroke


```text
fontawesome-6/Brands/SquareFontAwesomeStroke
```

```text
include('fontawesome-6/Brands/SquareFontAwesomeStroke')
```



| Illustration | SquareFontAwesomeStroke |
| :---: | :---: |
| ![illustration for Illustration](../../fontawesome-6/Brands/SquareFontAwesomeStroke.png) | ![illustration for SquareFontAwesomeStroke](../../fontawesome-6/Brands/SquareFontAwesomeStroke.Local.png) |




## SquareFontAwesomeStroke

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('fontawesome-6/bootstrap')

' loads the Item which embeds the element SquareFontAwesomeStroke
include('fontawesome-6/Brands/SquareFontAwesomeStroke')

' renders the element
SquareFontAwesomeStroke('SquareFontAwesomeStroke', 'Square Font Awesome Stroke', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('fontawesome-6/bootstrap')

' loads the Item which embeds the element SquareFontAwesomeStroke
include('fontawesome-6/Brands/SquareFontAwesomeStroke')

' renders the element
SquareFontAwesomeStroke('SquareFontAwesomeStroke', 'Square Font Awesome Stroke', 'an optional tech label')
@enduml
```

==> plantuml-libs-9.2.0.tgz: package/distribution/fontawesome-6/Brands/SquareFontAwesomeStroke.md <==
# SquareFontAwesomeStroke


```text
fontawesome-6/Brands/SquareFontAwesomeStroke
```

```text
include('fontawesome-6/Brands/SquareFontAwesomeStroke')
```



| Illustration | SquareFontAwesomeStroke |
| :---: | :---: |
| ![illustration for Illustration](../../fontawesome-6/Brands/SquareFontAwesomeStroke.png) | ![illustration for SquareFontAwesomeStroke](../../fontawesome-6/Brands/SquareFontAwesomeStroke.Local.png) |




## SquareFontAwesomeStroke

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('fontawesome-6/bootstrap')

' loads the Item which embeds the element SquareFontAwesomeStroke
include('fontawesome-6/Brands/SquareFontAwesomeStroke')

' renders the element
SquareFontAwesomeStroke('SquareFontAwesomeStroke', 'Square Font Awesome Stroke', 'an optional tech label', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('fontawesome-6/bootstrap')

' loads the Item which embeds the element SquareFontAwesomeStroke
include('fontawesome-6/Brands/SquareFontAwesomeStroke')

' renders the element
SquareFontAwesomeStroke('SquareFontAwesomeStroke', 'Square Font Awesome Stroke', 'an optional tech label', 'an optional description')
@enduml
```
